@@ -5,16 +5,24 @@ lascheck = function(data)
   if(sum(c("X", "Y", "Z") %in%fields) != 3)
     stop("No fields named X Y and Z found.", call. = F)
 
-  negvalues = sum(data$Z < 0)
+  negvalues = fast_countbelow(data$Z, 0)
 
   if(negvalues > 0)
     lidRError("LDR2", number = negvalues, behaviour = warning)
 
   if("Classification" %in% fields)
   {
-    class0 = sum(data$Classification == 0)
+    class0 = fast_countequal(data$Classification, 0)
 
     if(class0 > 0)
       lidRError("LDR3", number = class0, behaviour = warning)
   }
+
+  if("ReturnNumber" %in% fields)
+  {
+    class0 = fast_countequal(data$ReturnNumber, 0)
+
+    if(class0 > 0)
+      lidRError("LDR10", number = class0, behaviour = warning)
+  }
 }
\ No newline at end of file
